@@ -45,7 +45,7 @@ def post_request(query, session):
     }
 
     ## send search request
-    r = session.post('http://boldsystems.org/index.php/IDS_IdentificationRequest', data = seq_data, timeout = 300)
+    r = session.post('https://boldsystems.org/index.php/IDS_IdentificationRequest', data = seq_data, timeout = 300)
 
     ## extract Top20 table links from the BOLD Result page
     soup = BSoup(r.text, 'html5lib')
